"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateTurnstileToken = void 0;
function validateTurnstileToken({ token, secretKey, remoteip, idempotencyKey, sandbox = false, }) {
    return __awaiter(this, void 0, void 0, function* () {
        const endpoint = "https://challenges.cloudflare.com/turnstile/v0/siteverify";
        const sandboxDummyKey = () => {
            switch (sandbox) {
                case "pass":
                    return "1x0000000000000000000000000000000AA";
                case "fail":
                    return "2x0000000000000000000000000000000AA";
                case "error":
                    return "3x0000000000000000000000000000000AA";
            }
            return "1x0000000000000000000000000000000AA";
        };
        const formData = new URLSearchParams(Object.assign(Object.assign({ secret: sandbox ? sandboxDummyKey() : secretKey, response: token }, (remoteip && { remoteip })), (idempotencyKey && { idempotency_key: idempotencyKey })));
        try {
            const response = yield fetch(endpoint, {
                method: "POST",
                body: formData,
                headers: {
                    "Content-Type": "application/x-www-form-urlencoded",
                },
            });
            if (!response.ok) {
                throw new Error(`HTTP error! status: ${response.status}`);
            }
            return yield response.json();
        }
        catch (error) {
            throw new Error(`Failed to validate Turnstile token: ${error}`);
        }
    });
}
exports.validateTurnstileToken = validateTurnstileToken;
//# sourceMappingURL=validate.js.map